@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 """
 This module implements various transmuter classes.
 Transmuters are essentially classes that generate TransformedStructures from
@@ -8,9 +10,7 @@ It also includes the helper function, batch_write_vasp_input to generate an
 entire directory of vasp input files for running.
 """
 
-from __future__ import division
-from six.moves import filter
-from six.moves import map
+from six.moves import filter, map
 
 __author__ = "Shyue Ping Ong, Will Richards"
 __copyright__ = "Copyright 2012, The Materials Project"
