@@ -1,8 +1,9 @@
+from __future__ import division, unicode_literals
+
 """
 This module implements classes to perform bond valence analyses.
 """
 
-from __future__ import division
 
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2012, The Materials Project"
@@ -531,4 +532,4 @@ def add_oxidation_state_by_site_fraction(structure, oxidation_states):
             return structure
         except IndexError:
             raise ValueError("Oxidation state of all sites must be "
-                             "specified in the list.")
\ No newline at end of file
+                             "specified in the list.")
