@@ -1,8 +1,9 @@
+from __future__ import division, unicode_literals
+
 """
 This module implements an XRD pattern calculator.
 """
 
-from __future__ import division
 from six.moves import filter
 from six.moves import map
 from six.moves import zip
@@ -379,4 +380,4 @@ def get_unique_families(hkls):
         if not found:
             unique[hkl1] = 1
 
-    return unique
\ No newline at end of file
+    return unique
