@@ -1,8 +1,9 @@
+from __future__ import division, unicode_literals
+
 """
 This module provides classes to perform topological analyses of structures.
 """
 
-from __future__ import division
 
 __author__ = "Shyue Ping Ong, Geoffroy Hautier, Sai Jayaraman"
 __copyright__ = "Copyright 2011, The Materials Project"
@@ -342,7 +343,7 @@ def contains_peroxide(structure, relative_cutoff=1.1):
         Boolean indicating if structure contains a peroxide anion.
     """
     ox_type = oxide_type(structure, relative_cutoff)
-    if ox_type is "peroxide":
+    if ox_type == "peroxide":
         return True
     else:
         return False
