@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 """
 This package contains core modules and classes for representing structures and
 operations on them.
@@ -6,8 +8,7 @@ operations on them.
 __author__ = "Shyue Ping Ong"
 __date__ = "Dec 15, 2010 7:21:29 PM"
 
-from .periodic_table import Element, Specie, DummySpecie, \
-    get_el_sp
+from .periodic_table import Element, Specie, DummySpecie, get_el_sp
 from .composition import Composition
 from .structure import Structure, IStructure, Molecule, IMolecule
 from .bonds import CovalentBond, get_bond_length
