@@ -1,8 +1,9 @@
+from __future__ import division, unicode_literals
+
 """
 This module defines classes representing non-periodic and periodic sites.
 """
 
-from __future__ import division
 
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2012, The Materials Project"
@@ -108,7 +109,7 @@ class Site(collections.Mapping, collections.Hashable, PMGSONable):
         String representation of species on the site.
         """
         if self._is_ordered:
-            return str(list(self._species.keys())[0])
+            return list(self._species.keys())[0].__str__()
         else:
             sorted_species = sorted(self._species.keys())
             return ", ".join(["{}:{:.3f}".format(sp, self._species[sp])
@@ -419,34 +420,8 @@ class PeriodicSite(Site, PMGSONable):
             (distance, jimage): distance and periodic lattice translations
             of the other site for which the distance applies.
         """
-        if jimage is None:
-            #The following code is heavily vectorized to maximize speed.
-            #Get the image adjustment necessary to bring coords to unit_cell.
-            adj1 = np.floor(self._fcoords)
-            adj2 = np.floor(fcoords)
-            #Shift coords to unitcell
-            coord1 = self._fcoords - adj1
-            coord2 = fcoords - adj2
-            # Generate set of images required for testing.
-            # This is a cheat to create an 8x3 array of all length 3
-            # combinations of 0,1
-            test_set = np.unpackbits(np.array([5, 57, 119],
-                                              dtype=np.uint8)).reshape(8, 3)
-            images = np.copysign(test_set, coord1 - coord2)
-            # Create tiled cartesian coords for computing distances.
-            vec = np.tile(coord2 - coord1, (8, 1)) + images
-            vec = self._lattice.get_cartesian_coords(vec)
-            # Compute distances manually.
-            dist = np.sqrt(np.sum(vec ** 2, 1)).tolist()
-            # Return the minimum distance and the adjusted image corresponding
-            # to the min distance.
-            mindist = min(dist)
-            ind = dist.index(mindist)
-            return mindist, adj1 - adj2 + images[ind]
-
-        mapped_vec = self._lattice.get_cartesian_coords(jimage + fcoords
-                                                        - self._fcoords)
-        return np.linalg.norm(mapped_vec), jimage
+        return self._lattice.get_distance_and_image(self._fcoords, fcoords,
+                                                    jimage=jimage)
 
     def distance_and_image(self, other, jimage=None):
         """
