@@ -1,9 +1,10 @@
+from __future__ import division, unicode_literals
+
 """
 This module provides core classes needed by all define electronic structure,
 such as the Spin, Orbital, etc.
 """
 
-from __future__ import division
 
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2011, The Materials Project"
