@@ -1,8 +1,9 @@
+from __future__ import division, unicode_literals
+
 """
 This module defines classes to represent the density of states, etc.
 """
 
-from __future__ import division
 
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2012, The Materials Project"
