@@ -1,9 +1,10 @@
+from __future__ import division, unicode_literals
+
 """
 This module implements Compatibility corrections for mixing runs of different
 functionals.
 """
 
-from __future__ import division
 import six
 from six.moves import filter
 from six.moves import map
