@@ -1,7 +1,7 @@
+from __future__ import unicode_literals
 from .eos import *
 from .pseudos import *
 from .netcdf import *
-#from .events import *
 from .tasks import *
 from .workflows import *
 from .calculations import *
