@@ -1,8 +1,9 @@
+from __future__ import unicode_literals, division
+
 """
 This module provides objects for extracting timing data from the ABINIT output files 
 It also provides tools to analye and to visualize the parallel efficiency.
 """
-from __future__ import print_function, division
 
 import sys
 import collections
