@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 """
 Part of this code is based on a similar implementation present in FireWorks (https://pypi.python.org/pypi/FireWorks).
 Work done by D. Waroquiers, A. Jain, and M. Kocher.
@@ -9,7 +11,6 @@ This programmatic interface is used by the `TaskManager` for optimizing the para
 of the run before submitting the job (Abinit provides the autoparal option that 
 allows one to get a list of parallel configuration and their expected efficiency).
 """
-from __future__ import print_function, division
 
 import os
 import abc
