@@ -1,5 +1,6 @@
+from __future__ import unicode_literals, division
+
 """Tools and helper functions for abinit calculations"""
-from __future__ import print_function, division
 
 import os
 import collections
