@@ -1,4 +1,5 @@
-# coding=utf-8
+# coding: utf-8
+from __future__ import unicode_literals
 
 """
 This module implements input and output processing from QChem.
@@ -16,8 +17,7 @@ from pymatgen.core.structure import Molecule
 from pymatgen.core.units import Energy, FloatWithUnit
 from pymatgen.serializers.json_coders import PMGSONable
 from pymatgen.util.coord_utils import get_angle
-from six.moves import map
-from six.moves import zip
+from six.moves import map, zip
 
 __author__ = "Xiaohui Qu"
 __copyright__ = "Copyright 2013, The Electrolyte Genome Project"
@@ -354,7 +354,7 @@ class QcTask(PMGSONable):
 
     def set_integral_threshold(self, thresh=12):
         """
-        Cutoff for neglect of two electron integrals. 10−THRESH (THRESH ≤ 14).
+        Cutoff for neglect of two electron integrals. 10−THRESH (THRESH <= 14).
         In QChem, the default values are:
         8	For single point energies.
         10	For optimizations and frequency calculations.
@@ -723,12 +723,12 @@ class QcTask(PMGSONable):
                       optional_params=optional_params)
 
     def write_file(self, filename):
-        with zopen(filename, "w") as f:
+        with zopen(filename, "wt") as f:
             f.write(self.__str__())
 
     @classmethod
     def from_file(cls, filename):
-        with zopen(filename) as f:
+        with zopen(filename, "rt") as f:
             return cls.from_string(f.read())
 
     @classmethod
@@ -1133,7 +1133,7 @@ class QcInput(PMGSONable):
         return "\n@@@\n\n\n".join([str(j) for j in self.jobs])
 
     def write_file(self, filename):
-        with zopen(filename, "w") as f:
+        with zopen(filename, "wt") as f:
             f.write(self.__str__())
 
     def as_dict(self):
@@ -1154,7 +1154,7 @@ class QcInput(PMGSONable):
 
     @classmethod
     def from_file(cls, filename):
-        with zopen(filename) as f:
+        with zopen(filename, "rt") as f:
             return cls.from_string(f.read())
 
 
@@ -1164,7 +1164,7 @@ class QcOutput(object):
 
     def __init__(self, filename):
         self.filename = filename
-        with zopen(filename) as f:
+        with zopen(filename, "rt") as f:
             data = f.read()
         chunks = re.split("\n\nRunning Job \d+ of \d+ \S+", data)
         # noinspection PyTypeChecker
