@@ -1,3 +1,5 @@
+from __future__ import division, unicode_literals
+
 """
 This module provides classes to interface with the Materials Project REST
 API v2 to enable the creation of data structures and pymatgen objects using
@@ -8,7 +10,6 @@ Materials Project, and obtain an API key by going to your dashboard at
 https://www.materialsproject.org/dashboard.
 """
 
-from __future__ import division
 
 __author__ = "Shyue Ping Ong, Shreyas Cholia"
 __credits__ = "Anubhav Jain"
@@ -24,8 +25,6 @@ import json
 import warnings
 import re
 import itertools
-import datetime
-import numpy as np
 
 from monty.json import MontyEncoder, MontyDecoder
 
@@ -845,4 +844,4 @@ class MPDecoder(MontyDecoder):
                     return cls_.from_dict(data)
             return {self.process_decoded(k): self.process_decoded(v)
                     for k, v in d.items()}
-        return MontyDecoder.process_decoded(self, d)
\ No newline at end of file
+        return MontyDecoder.process_decoded(self, d)
