@@ -1,8 +1,9 @@
+from __future__ import division, unicode_literals
+
 """
 This module contains an algorithm to solve the Linear Assignment Problem
 """
 
-from __future__ import division
 
 __author__ = "Will Richards"
 __copyright__ = "Copyright 2011, The Materials Project"
