@@ -1,8 +1,9 @@
+from __future__ import division, unicode_literals
+
 """
 This module provides classes for analyzing phase diagrams.
 """
 
-from __future__ import division
 from six.moves import filter
 from six.moves import zip
 
@@ -471,4 +472,4 @@ class PDAnalyzer(object):
         for i in range(len(elts)):
             res[elts[i]] = (min_mus[i] + muref[i], max_mus[i] + muref[i])
         res[open_elt] = (min_open, max_open)
-        return res
\ No newline at end of file
+        return res
