@@ -1,8 +1,9 @@
+from __future__ import division, unicode_literals
+
 """
 This module provides classes to create phase diagrams.
 """
 
-from __future__ import division
 from six.moves import filter
 
 __author__ = "Shyue Ping Ong"
