@@ -1,8 +1,9 @@
+from __future__ import division, unicode_literals
+
 """
 This module implements more advanced transformations.
 """
 
-from __future__ import division
 
 __author__ = "Shyue Ping Ong, Stephen Dacek"
 __copyright__ = "Copyright 2012, The Materials Project"
